Documentation
¶
Overview ¶
Package gomind for a simple Multi Layer Perceptron (MLP) Feed Forward Artificial Neural Network library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model type defines the neural network's architecture and metadata.
func New ¶
func New(configuration *ModelConfiguration) (*Model, error)
New is used to create a new GoMind network model.
func (*Model) CalculateError ¶
CalculateError function generates the error value for the given target output against the network's last output.
func (*Model) Describe ¶
Describe function prints the current state of the neural network and its components.
func (*Model) LastOutput ¶
LastOutput function returns the last output of the network.
func (*Model) LearnSample ¶
LearnSample function trains the neural network using the given input/output sample.
type ModelConfiguration ¶
type ModelConfiguration struct {
NumberOfInputs int // mandatory
NumberOfOutputs int // mandatory
NumberOfHiddenLayerNeurons int
LearningRate float64
HiddenLayerActivationFunctionName string
OutputLayerActivationFunctionName string
}
ModelConfiguration type defines the network configuration template filled by external code while creating a new model.
type NeuralNetworkInterface ¶
type NeuralNetworkInterface interface {
CalculateOutput(input []float64) []float64
LastOutput() []float64
HiddenLayer() *layer.Layer
OutputLayer() *layer.Layer
CalculateNewOutputLayerWeights(outputs, targetOutputs []float64) error
CalculateNewHiddenLayerWeights() error
UpdateWeights()
CalculateError(targetOutput []float64) (float64, error)
}
NeuralNetworkInterface defines methods used by gomind from network.NeuralNetwork's type.